@@ -26,7 +26,7 @@ def __create_completer(commands: list, pattern_str: str = "$") -> WordCompleter:
     return WordCompleter(words=commands, pattern=re.compile(pattern_str))
 
 
-def get_input(
+def __get_input(
     session: PromptSession = None,
     completer: WordCompleter = None,
     key_bindings: KeyBindings = None,
@@ -49,6 +49,9 @@ def get_input(
 class Chatbot:
     """
     A class to interact with Google Bard.
+    Parameters
+        session_id: str
+            The __Secure-1PSID cookie.
     """
 
     __slots__ = [
@@ -95,7 +98,7 @@ class Chatbot:
         """
         # url params
         params = {
-            "bl": "boq_assistant-bard-web-server_20230315.04_p2",
+            "bl": "boq_assistant-bard-web-server_20230326.21_p0",
             "_reqid": str(self._reqid),
             "rt": "c",
         }
@@ -113,7 +116,7 @@ class Chatbot:
 
         # do the request!
         resp = self.session.post(
-            "https://bard.google.com/_/BardChatUi/data/assistant.lamda.BardFrontendService/StreamGenerate",
+            "https://bard.google.com/u/1/_/BardChatUi/data/assistant.lamda.BardFrontendService/StreamGenerate",
             params=params,
             data=data,
             timeout=120,
@@ -141,7 +144,7 @@ class Chatbot:
 if __name__ == "__main__":
     print(
         """
-        ChatGPT - A command-line interface to Google's Bard (https://bard.google.com/)
+        Bard - A command-line interface to Google's Bard (https://bard.google.com/)
         Repo: github.com/acheong08/Bard
 
         Enter `alt+enter` or `esc+enter` to send a message.
@@ -163,7 +166,7 @@ if __name__ == "__main__":
     try:
         while True:
             console.print("You:")
-            user_prompt = get_input(session=prompt_session, completer=completions)
+            user_prompt = __get_input(session=prompt_session, completer=completions)
             console.print()
             if user_prompt == "!exit":
                 break
